# eric7.MicroPython.WifiDialogs.WifiApConfigDialog

Module implementing a dialog to configure the Access Point interface.

### Global Attributes

None

### Classes

WifiApConfigDialog | Class implementing a dialog to configure the Access Point interface.

### Functions

None

## WifiApConfigDialog

Class implementing a dialog to configure the Access Point interface.

### Derived from

QDialog, Ui_WifiApConfigDialog

### Class Attributes

None

### Class Methods

None

### Methods

WifiApConfigDialog | Constructor
__updateOk | Private method to update the enabled state of the OK button.
accept | Public slot accepting the dialog.
getApConfig | Public method to get the entered access point configuration data.
on_apShowPasswordButton_clicked | Private slot to show or hide the WiFi Access Point password.

### Static Methods

None

#### WifiApConfigDialog (Constructor)

WifiApConfigDialog(withIP, parent=None)

Constructor

withIP (bool)
  flag indicating to ask the user for an IP configuration
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### WifiApConfigDialog.__updateOk

__updateOk()

Private method to update the enabled state of the OK button.

#### WifiApConfigDialog.accept

accept()

Public slot accepting the dialog.

#### WifiApConfigDialog.getApConfig

getApConfig()

Public method to get the entered access point configuration data.

Return:
  tuple containing the SSID, the password, the selected security mode and a tuple with the IPv4 address, the netmask, the gateway address and the resolver address

Return Type:
  tuple of (str, str, int, (str, str, str, str))

#### WifiApConfigDialog.on_apShowPasswordButton_clicked

on_apShowPasswordButton_clicked(checked)

Private slot to show or hide the WiFi Access Point password.

checked (bool)
  state of the button

Up